/****************************************************************************/
/*																			*/
/*	HERON_HSB.C																*/
/*																			*/
/*	(c) 2001 Hunt Engineering												*/
/*	    All Rights Reserved													*/
/*																			*/
/*	This is an example C source file that shows how to use the Heron Serial	*/
/*	Bus (HSB) functions of the HERON-API. In particular, this example shows	*/
/*	the use of the functions 'HeronHsbReceiveMessage' and					*/
/*	'HeronHsbSendMessage'.													*/
/*																			*/
/*	The example expects to receive a message from the host HSB device that	*/
/*	contains 10 data bytes. Once received the message data is returned by	*/
/*	sending a message back to the host HSB device.							*/
/*																			*/
/*	For a more detailed description of this example please refer to the		*/
/*	document 'hsb_example.pdf' that accompanies this example source file.	*/
/*																			*/
/* 	Version	  Date	Version Author	Comments								*/
/*	-------	  ----	--------------	--------								*/
/*																			*/
/*    1.0	 26/3/01	  RW		Example first written					*/
/*																			*/
/****************************************************************************/
#include <stdio.h>
#include <std.h>
#include <tsk.h>


/* The following line must include the HERON-API header file for the HERON  */
/* module type you are using. This line will be automatically set to the    */
/* correct header file if you create the project using the HUNT ENGINEERING */
/* 'Create new Project' plug-in.											*/
#include "heron4.h"


#pragma FUNC_EXT_CALLED(maintask)          


#define SIZE	 10	    /* Number of data bytes transferred in each message */
#define BOARD	 0	/* Board ID of the HSB device with which to communicate */
#define HOST_HSB 0x05	        /* Slot ID of the HSB device on the carrier */
                    

int main(void)
{
}
                

/* A task object must exist in the CDB file for this project. This object	*/
/* must define a function called 'maintask' which will enable the following */
/* function to be scheduled.												*/
/* Please note, the default CDB templates provided by HUNT ENGINEERING will */
/* automatically contain this task object.									*/
int maintask(void)
{
int i,j,status;
int bd,slot,msg_type;
unsigned int done;
unsigned char rx_data[SIZE];
unsigned char tx_data[SIZE];
HeronHSB *handle;


printf("The HSB example program has started\n");

handle = HeronHsbOpen();
if (handle == NULL) {
	printf("Error: Call to HeronHsbOpen failed, error = %d\n",heronerr); 
	exit(0);
}
                  
bd = BOARD;                  
slot = HOST_HSB;

for (j=0;j<10;j++) {
	/* Receive a message from the host HSB device */
	for (i=0;i<SIZE;i++) rx_data[i] = 0;

	status = HeronHsbReceiveMessage(handle,&msg_type,bd,slot,rx_data,SIZE,&done);
	if (status == HERON_OK) printf("Message was received succesfully\n");
	else {
		printf("Failed to receive message (error = %d)\n",status);    
		exit(0);
	}
	printf("Message contained %d optional data bytes\n",done);

	/* Send a message to the host HSB device */
	for (i=0;i<SIZE;i++) tx_data[i] = rx_data[i];                      
	
	msg_type++;
	status = HeronHsbSendMessage(handle,msg_type,bd,slot,tx_data,SIZE);
	if (status == HERON_OK) printf("Message was sent succesfully\n");
	else {
		printf("Failed to send message (error = %d)\n",status);   
		exit(0);
	}
}
          
printf("Finished sending and receiving messages\n");          
status = HeronHsbClose(handle);
if (status != HERON_OK) {
	printf("Error: Call to HeronHsbOpen failed, error = %d\n",heronerr);
}

return(0);
}

