/******************************************************************************/
/* 													*/
/*	EXAMPLE.C											*/
/* 													*/
/*	(c) 2000 Hunt Engineering								*/
/*	    All Rights Reserved									*/
/*													*/
/*	This is an example C source file that shows how to use the Streaming	*/
/*	I/O (SIO) functions of the HERON-API. In particular, this example shows */
/*	the use of the function 'HeronSioRead' to read at high speed from a	*/
/*	HERON FIFO.											*/
/*													*/
/*	For a more detailed description of the SIO model please refer to the	*/
/*	document 'sio_example.pdf' that accompanies this example source file.	*/
/*													*/
/* 	Version	  Date	Version Author	Comments				*/
/*	-------	  ----	--------------	--------				*/
/* 													*/
/*      1.0		 1/9/00		RW		Example first written         */
/* 													*/
/******************************************************************************/
#include <std.h>
#include <tsk.h> 
#include <sio.h>
#include <stdio.h>


/* We are using the HERON-API for the HERON1 so you must include the next line*/
#include "heron1.h"


/* YOU need to set this value to reflect which FIFO connection to use for the */
/* SIO transfer */
#define FIFONO	2			   /* FIFO through which Data is received */


#define N		100				    /* Number of buffers to process */


/* BUFSIZE is the number of 32-bit words in each buffer. This number must	*/
/* equal the SIO object buffer size when multiplied by four, as the SIO object*/
/* defines the buffer size in bytes.							*/
#define BUFSIZE	100
/* For example with a BUFSIZE of 100, the buffer size in the SIO object 	*/
/* properties must be set to 400.								*/


/* A 'sio_stream' SIO object must be created in the CDB file with which this	*/
/* source file is used. The SIO object must be set up as input stream and use	*/
/* one of the FIFO read SIO device drivers supplied in the standard HUNT ENG- */
/* INEERING CDB templates. */
extern far SIO_Obj sio_stream;	   /* stream object */
SIO_Handle s_handle = &sio_stream;     /* stream handle */  
    

HeronFIFO *handle;    
    

int main(void)
{
return(0);
}
   
   
void mainTask(void)
{
int i,j;
int status;
unsigned int sum;
unsigned int trash_count;
volatile unsigned int *data = NULL;


printf("The SIO example program is running\n"); 

/* Call HeronSioOpenFifo to open a FIFO for reading with streaming I/O */
/* This call will return a pointer to a buffer in the last argument    */
/* This pointer should be used by the first call to HeronSioRead	     */
handle = HeronSioOpenFifo(FIFONO,"r",s_handle,(Ptr *)&data);
if (handle == NULL) {
	printf("Error opening fifo %d, error = %d\n",FIFONO,heronerr);
}

/* Release the Config line so that a connected I/O module can begin operation */
HeronConfigOff();

/* Process N buffers */
for (i=0;i<N;i++) {
	/* For each call to HeronSioRead, an empty buffer is returned to the SIO*/
	/* driver, and a full buffer is returned.						*/
	HeronSioRead(handle,(Ptr *)&data);

	/* Process the buffer */
	/* This example simply sums all of the elements of each buffer received */
	sum = 0;
	for (j=0;j<BUFSIZE;j++) {
		sum += data[j];
	}
}

/* Use the SIO_ctrl function to find out how many times the trash buffer was  */
/* used. The second argument must be set to 0 for the SIO_ctrl call to return */
/* the count of how many times the trash buffer was used.				*/
status = SIO_ctrl(s_handle,0,(Arg)&trash_count);
printf("The trash buffer was used %d times\n",trash_count);

printf("End of the SIO example program\n");

return;
} /* End of mainTask */